@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,17 +16,20 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -106,6 +109,42 @@ class TranslationServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return TranslationServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> TranslationServiceTransport:
         """Returns the transport used by the client instance.
@@ -183,6 +222,27 @@ class TranslationServiceAsyncClient:
     ) -> translation_service.TranslateTextResponse:
         r"""Translates input text and returns translated text.
 
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_translate_text():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                request = translate_v3.TranslateTextRequest(
+                    contents=['contents_value_1', 'contents_value_2'],
+                    target_language_code="target_language_code_value",
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.translate_text(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.TranslateTextRequest, dict]):
                 The request object. The request message for synchronous
@@ -282,7 +342,7 @@ class TranslationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any(
             [
@@ -351,6 +411,26 @@ class TranslationServiceAsyncClient:
     ) -> translation_service.DetectLanguageResponse:
         r"""Detects the language of text within a request.
 
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_detect_language():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                request = translate_v3.DetectLanguageRequest(
+                    content="content_value",
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.detect_language(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.DetectLanguageRequest, dict]):
                 The request object. The request message for language
@@ -418,7 +498,7 @@ class TranslationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, model, mime_type, content])
         if request is not None and has_flattened_params:
@@ -474,6 +554,26 @@ class TranslationServiceAsyncClient:
         r"""Returns a list of supported languages for
         translation.
 
+
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_get_supported_languages():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                request = translate_v3.GetSupportedLanguagesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.get_supported_languages(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.GetSupportedLanguagesRequest, dict]):
                 The request object. The request message for discovering
@@ -539,7 +639,7 @@ class TranslationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, model, display_language_code])
         if request is not None and has_flattened_params:
@@ -599,6 +699,30 @@ class TranslationServiceAsyncClient:
     ) -> translation_service.TranslateDocumentResponse:
         r"""Translates documents in synchronous mode.
 
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_translate_document():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                document_input_config = translate_v3.DocumentInputConfig()
+                document_input_config.content = b'content_blob'
+
+                request = translate_v3.TranslateDocumentRequest(
+                    parent="parent_value",
+                    target_language_code="target_language_code_value",
+                    document_input_config=document_input_config,
+                )
+
+                # Make the request
+                response = client.translate_document(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.TranslateDocumentRequest, dict]):
                 The request object. A document translation request.
@@ -655,6 +779,40 @@ class TranslationServiceAsyncClient:
         use google.longrunning.Operation.name to poll the status
         of the call.
 
+
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_batch_translate_text():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                input_configs = translate_v3.InputConfig()
+                input_configs.gcs_source.input_uri = "input_uri_value"
+
+                output_config = translate_v3.OutputConfig()
+                output_config.gcs_destination.output_uri_prefix = "output_uri_prefix_value"
+
+                request = translate_v3.BatchTranslateTextRequest(
+                    parent="parent_value",
+                    source_language_code="source_language_code_value",
+                    target_language_codes=['target_language_codes_value_1', 'target_language_codes_value_2'],
+                    input_configs=input_configs,
+                    output_config=output_config,
+                )
+
+                # Make the request
+                operation = client.batch_translate_text(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.BatchTranslateTextRequest, dict]):
                 The request object. The batch translation request.
@@ -728,6 +886,40 @@ class TranslationServiceAsyncClient:
         google.longrunning.Operation.name to poll the status of
         the call.
 
+
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_batch_translate_document():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                input_configs = translate_v3.BatchDocumentInputConfig()
+                input_configs.gcs_source.input_uri = "input_uri_value"
+
+                output_config = translate_v3.BatchDocumentOutputConfig()
+                output_config.gcs_destination.output_uri_prefix = "output_uri_prefix_value"
+
+                request = translate_v3.BatchTranslateDocumentRequest(
+                    parent="parent_value",
+                    source_language_code="source_language_code_value",
+                    target_language_codes=['target_language_codes_value_1', 'target_language_codes_value_2'],
+                    input_configs=input_configs,
+                    output_config=output_config,
+                )
+
+                # Make the request
+                operation = client.batch_translate_document(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.BatchTranslateDocumentRequest, dict]):
                 The request object. The BatchTranslateDocument request.
@@ -805,7 +997,7 @@ class TranslationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any(
             [
@@ -878,6 +1070,34 @@ class TranslationServiceAsyncClient:
         r"""Creates a glossary and returns the long-running operation.
         Returns NOT_FOUND, if the project doesn't exist.
 
+
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_create_glossary():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                glossary = translate_v3.Glossary()
+                glossary.name = "name_value"
+
+                request = translate_v3.CreateGlossaryRequest(
+                    parent="parent_value",
+                    glossary=glossary,
+                )
+
+                # Make the request
+                operation = client.create_glossary(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.CreateGlossaryRequest, dict]):
                 The request object. Request message for CreateGlossary.
@@ -907,7 +1127,7 @@ class TranslationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, glossary])
         if request is not None and has_flattened_params:
@@ -965,6 +1185,27 @@ class TranslationServiceAsyncClient:
         r"""Lists glossaries in a project. Returns NOT_FOUND, if the project
         doesn't exist.
 
+
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_list_glossaries():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                request = translate_v3.ListGlossariesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_glossaries(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.ListGlossariesRequest, dict]):
                 The request object. Request message for ListGlossaries.
@@ -991,7 +1232,7 @@ class TranslationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1055,6 +1296,26 @@ class TranslationServiceAsyncClient:
         r"""Gets a glossary. Returns NOT_FOUND, if the glossary doesn't
         exist.
 
+
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_get_glossary():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                request = translate_v3.GetGlossaryRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_glossary(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.GetGlossaryRequest, dict]):
                 The request object. Request message for GetGlossary.
@@ -1078,7 +1339,7 @@ class TranslationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1137,6 +1398,30 @@ class TranslationServiceAsyncClient:
         glossary isn't created yet. Returns NOT_FOUND, if the glossary
         doesn't exist.
 
+
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_delete_glossary():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                request = translate_v3.DeleteGlossaryRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_glossary(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.DeleteGlossaryRequest, dict]):
                 The request object. Request message for DeleteGlossary.
@@ -1163,7 +1448,7 @@ class TranslationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
