@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,23 +14,25 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
 from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -237,6 +239,73 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -287,50 +356,22 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, TranslationServiceTransport):
             # transport is a TranslationServiceTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -342,6 +383,15 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -370,6 +420,27 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
     ) -> translation_service.TranslateTextResponse:
         r"""Translates input text and returns translated text.
 
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_translate_text():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                request = translate_v3.TranslateTextRequest(
+                    contents=['contents_value_1', 'contents_value_2'],
+                    target_language_code="target_language_code_value",
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.translate_text(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.TranslateTextRequest, dict]):
                 The request object. The request message for synchronous
@@ -469,7 +540,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any(
             [
@@ -538,6 +609,26 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
     ) -> translation_service.DetectLanguageResponse:
         r"""Detects the language of text within a request.
 
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_detect_language():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                request = translate_v3.DetectLanguageRequest(
+                    content="content_value",
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.detect_language(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.DetectLanguageRequest, dict]):
                 The request object. The request message for language
@@ -605,7 +696,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, model, mime_type, content])
         if request is not None and has_flattened_params:
@@ -661,6 +752,26 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         r"""Returns a list of supported languages for
         translation.
 
+
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_get_supported_languages():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                request = translate_v3.GetSupportedLanguagesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.get_supported_languages(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.GetSupportedLanguagesRequest, dict]):
                 The request object. The request message for discovering
@@ -726,7 +837,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, model, display_language_code])
         if request is not None and has_flattened_params:
@@ -776,6 +887,30 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
     ) -> translation_service.TranslateDocumentResponse:
         r"""Translates documents in synchronous mode.
 
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_translate_document():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                document_input_config = translate_v3.DocumentInputConfig()
+                document_input_config.content = b'content_blob'
+
+                request = translate_v3.TranslateDocumentRequest(
+                    parent="parent_value",
+                    target_language_code="target_language_code_value",
+                    document_input_config=document_input_config,
+                )
+
+                # Make the request
+                response = client.translate_document(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.TranslateDocumentRequest, dict]):
                 The request object. A document translation request.
@@ -833,6 +968,40 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         use google.longrunning.Operation.name to poll the status
         of the call.
 
+
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_batch_translate_text():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                input_configs = translate_v3.InputConfig()
+                input_configs.gcs_source.input_uri = "input_uri_value"
+
+                output_config = translate_v3.OutputConfig()
+                output_config.gcs_destination.output_uri_prefix = "output_uri_prefix_value"
+
+                request = translate_v3.BatchTranslateTextRequest(
+                    parent="parent_value",
+                    source_language_code="source_language_code_value",
+                    target_language_codes=['target_language_codes_value_1', 'target_language_codes_value_2'],
+                    input_configs=input_configs,
+                    output_config=output_config,
+                )
+
+                # Make the request
+                operation = client.batch_translate_text(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.BatchTranslateTextRequest, dict]):
                 The request object. The batch translation request.
@@ -907,6 +1076,40 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         google.longrunning.Operation.name to poll the status of
         the call.
 
+
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_batch_translate_document():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                input_configs = translate_v3.BatchDocumentInputConfig()
+                input_configs.gcs_source.input_uri = "input_uri_value"
+
+                output_config = translate_v3.BatchDocumentOutputConfig()
+                output_config.gcs_destination.output_uri_prefix = "output_uri_prefix_value"
+
+                request = translate_v3.BatchTranslateDocumentRequest(
+                    parent="parent_value",
+                    source_language_code="source_language_code_value",
+                    target_language_codes=['target_language_codes_value_1', 'target_language_codes_value_2'],
+                    input_configs=input_configs,
+                    output_config=output_config,
+                )
+
+                # Make the request
+                operation = client.batch_translate_document(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.BatchTranslateDocumentRequest, dict]):
                 The request object. The BatchTranslateDocument request.
@@ -984,7 +1187,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any(
             [
@@ -1057,6 +1260,34 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         r"""Creates a glossary and returns the long-running operation.
         Returns NOT_FOUND, if the project doesn't exist.
 
+
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_create_glossary():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                glossary = translate_v3.Glossary()
+                glossary.name = "name_value"
+
+                request = translate_v3.CreateGlossaryRequest(
+                    parent="parent_value",
+                    glossary=glossary,
+                )
+
+                # Make the request
+                operation = client.create_glossary(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.CreateGlossaryRequest, dict]):
                 The request object. Request message for CreateGlossary.
@@ -1086,7 +1317,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, glossary])
         if request is not None and has_flattened_params:
@@ -1144,6 +1375,27 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         r"""Lists glossaries in a project. Returns NOT_FOUND, if the project
         doesn't exist.
 
+
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_list_glossaries():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                request = translate_v3.ListGlossariesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_glossaries(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.ListGlossariesRequest, dict]):
                 The request object. Request message for ListGlossaries.
@@ -1170,7 +1422,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1224,6 +1476,26 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         r"""Gets a glossary. Returns NOT_FOUND, if the glossary doesn't
         exist.
 
+
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_get_glossary():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                request = translate_v3.GetGlossaryRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_glossary(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.GetGlossaryRequest, dict]):
                 The request object. Request message for GetGlossary.
@@ -1247,7 +1519,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1296,6 +1568,30 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         glossary isn't created yet. Returns NOT_FOUND, if the glossary
         doesn't exist.
 
+
+        .. code-block:: python
+
+            from google.cloud import translate_v3
+
+            def sample_delete_glossary():
+                # Create a client
+                client = translate_v3.TranslationServiceClient()
+
+                # Initialize request argument(s)
+                request = translate_v3.DeleteGlossaryRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_glossary(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.translate_v3.types.DeleteGlossaryRequest, dict]):
                 The request object. Request message for DeleteGlossary.
@@ -1322,7 +1618,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
