@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -76,8 +76,9 @@ class TranslateTextGlossaryConfig(proto.Message):
             -  User provided custom glossary:
                ``projects/{project-number-or-id}/locations/{location-id}/glossaries/{glossary-id}``
         ignore_case (bool):
-            Optional. Indicates match is case-
-            nsensitive. Default value is false if missing.
+            Optional. Indicates match is
+            case-insensitive. Default value is false if
+            missing.
     """
 
     glossary = proto.Field(proto.STRING, number=1,)
@@ -565,6 +566,7 @@ class OutputConfig(proto.Message):
             glossary_error_file will be generated that contains error
             details. glossary_error_file has format of
             gs://translation_test/a_b_c\_'trg'_glossary_errors.[extension]
+
             This field is a member of `oneof`_ ``destination``.
     """
 
@@ -592,6 +594,7 @@ class DocumentInputConfig(proto.Message):
         gcs_source (google.cloud.translate_v3.types.GcsSource):
             Google Cloud Storage location. This must be a single file.
             For example: gs://example_bucket/example_file.pdf
+
             This field is a member of `oneof`_ ``source``.
         mime_type (str):
             Specifies the input document's mime_type.
